CharsetDecodeErrorKind

Enum CharsetDecodeErrorKind 

pub enum CharsetDecodeErrorKind {
    MalformedSequence {
        value: Option<u32>,
    },
    IncompleteSequence {
        required: usize,
        available: usize,
    },
    InvalidCodePoint {
        value: u32,
    },
}
Classifies failures detected while decoding encoded units into Unicode text.

Variants



MalformedSequence

The input units do not form a well-formed encoded sequence.

Fields

value: Option<u32>

Optional malformed raw value captured from the offending input unit.



IncompleteSequence

The closed input ended before a complete character was available.

Fields

required: usize

Total units required to complete the current sequence.

available: usize

Total units currently available from the start of the current sequence.



InvalidCodePoint

The decoded numeric value is not a valid Unicode scalar value.

Fields

value: u32

Raw decoded code-point value.

Implementations

Source

impl CharsetDecodeErrorKind

pub const fn required(self) -> Option<usize>

Returns the number of required input units for this kind, if available.

Returns
pub const fn available(self) -> Option<usize>

Returns the number of currently available input units for this kind, if available.

Returns
pub const fn value(self) -> Option<u32>

Returns the raw malformed value associated with this decoding error, if any.

Returns