CharsetEncodeErrorKind

Enum CharsetEncodeErrorKind 

pub enum CharsetEncodeErrorKind {
    InvalidCodePoint {
        value: u32,
    },
    InvalidInputIndex {
        input_len: usize,
    },
    UnmappableCharacter {
        value: u32,
    },
    BufferTooSmall {
        required: usize,
        available: usize,
    },
}
Classifies failures detected while encoding Unicode text into encoded units.

Variants



InvalidCodePoint

The supplied code point is not a valid Unicode scalar value.

Fields

value: u32

Raw code point value reported by the codec.



InvalidInputIndex

The requested input character index is outside the input buffer.

Fields

input_len: usize

Length of the input provided to the codec call.



UnmappableCharacter

The character cannot be represented by the target encoding.

Fields

value: u32

Raw character value that cannot be represented.



BufferTooSmall

The supplied output buffer is too small for the encoded character.

Fields

required: usize

Total units required to encode the character.

available: usize

Total units currently available for the requested output index.

Implementations

Source

impl CharsetEncodeErrorKind

pub const fn value(self) -> Option<u32>

Returns the raw value associated with the error kind, if available.

Returns
pub const fn required(self) -> Option<usize>

Returns the number of required output units for this kind, if available.

Returns
pub const fn available(self) -> Option<usize>

Returns the number of currently available output units for this kind, if available.

Returns
pub const fn input_len(self) -> Option<usize>

Returns the input length when this error comes from an invalid input index.

Returns