CharsetConverter

Struct CharsetConverter 

pub struct CharsetConverter<D, E>{ /* private fields */ }
Converts units encoded with one charset into units encoded with another charset.

The converter owns a CharsetDecoder for the source charset and a CharsetEncoder for the target charset. A decoded character may be kept pending between calls when the target output buffer is full.

Type Parameters

  • D: Low-level charset codec used by the source decoder.
  • E: Low-level charset codec used by the target encoder.
use qubit_text_codec::{Coder, CharsetDecoder, CharsetEncoder, CharsetConverter, Utf8Codec, Utf16U16Codec};

let mut converter = CharsetConverter::new(
    CharsetDecoder::new(Utf8Codec),
    CharsetEncoder::new(Utf16U16Codec),
);
let mut output = [0_u16; 2];

let progress = converter
    .convert("AB".as_bytes(), 0, &mut output, 0)
    .expect("convert bytes to utf-16");

assert_eq!(2, progress.read());
assert_eq!(2, progress.written());
assert_eq!([65, 66], output);

Implementations

Source

impl<D, E> CharsetConverter<D, E>

pub fn from_codecs(source: D, target: E) -> Self

Creates a charset converter from raw source and target codecs.

Parameters
  • source: Source charset codec.
  • target: Target charset codec.
Returns

Returns a converter with default decoder and encoder policies.

pub fn new(decoder: CharsetDecoder<D>, encoder: CharsetEncoder<E>) -> Self

Creates a charset converter from a decoder and an encoder.

Parameters
  • decoder: Decoder configured for the source charset.
  • encoder: Encoder configured for the target charset.
Returns

Returns a converter that composes the supplied decoder and encoder.

pub const fn decoder(&self) -> &CharsetDecoder<D>

Returns the source decoder.

Returns

Returns a shared reference to the configured decoder.

pub const fn encoder(&self) -> &CharsetEncoder<E>

Returns the target encoder.

Returns

Returns a shared reference to the configured encoder.

pub fn decoder_mut(&mut self) -> &mut CharsetDecoder<D>

Returns a mutable source decoder.

Returns

Returns a mutable reference to the configured decoder.

pub fn encoder_mut(&mut self) -> &mut CharsetEncoder<E>

Returns a mutable target encoder.

Returns

Returns a mutable reference to the configured encoder.