pub struct Utf32ByteCodec { /* private fields */ }Expand description
Combined byte-serialized UTF-32 codec.
The codec uses one configured byte order for both decoding and encoding. It
does not detect, consume, or emit a BOM automatically; callers should use
crate::UnicodeBom when a byte stream may carry an explicit BOM.
Examples
use qubit_text_codec::{
ByteOrder,
CharsetCodec,
DecodeStatus,
Charset,
Utf32,
Utf32ByteCodec,
};
let codec = Utf32ByteCodec::new(ByteOrder::BigEndian);
assert_eq!(Charset::UTF_32BE, codec.charset());
assert_eq!(Utf32::MAX_BYTES_PER_CHAR, codec.max_units_per_char());
let mut output = [0_u8; Utf32::MAX_BYTES_PER_CHAR];
let written = codec.encode_one('中', &mut output, 0).expect("buffer fits");
assert_eq!(
DecodeStatus::Complete {
value: '中',
consumed: written,
},
codec.decode_one(&output[..written], 0).expect("valid UTF-32BE"),
);Implementations
Sourceimpl Utf32ByteCodec
impl Utf32ByteCodec
Sourcepub const fn byte_order(self) -> ByteOrder
pub const fn byte_order(self) -> ByteOrder
Sourcepub const fn charset(self) -> Charset
pub const fn charset(self) -> Charset
Returns the fixed-endian UTF-32 charset descriptor.
Returns
Returns Charset::UTF_32LE or Charset::UTF_32BE according to this
codec’s configured byte order.
Sourcepub const fn max_units_per_char(self) -> usize
pub const fn max_units_per_char(self) -> usize
Returns the maximum number of serialized UTF-32 bytes for one character.
Returns
Returns Utf32::MAX_BYTES_PER_CHAR.