pub enum CharsetDecodeErrorKind {
MalformedSequence {
value: Option<u32>,
},
IncompleteSequence {
required: usize,
available: usize,
},
InvalidCodePoint {
value: u32,
},
}Expand description
Classifies failures detected while decoding encoded units into Unicode text.
Variants
MalformedSequence
The input units do not form a well-formed encoded sequence.
IncompleteSequence
The closed input ended before a complete character was available.
Fields
InvalidCodePoint
The decoded numeric value is not a valid Unicode scalar value.
Implementations
Sourceimpl CharsetDecodeErrorKind
impl CharsetDecodeErrorKind
Sourcepub const fn required(self) -> Option<usize>
pub const fn required(self) -> Option<usize>
Returns the number of required input units for this kind, if available.
Returns
Some(required)forSelf::IncompleteSequence;Nonefor all other variants.
Sourcepub const fn available(self) -> Option<usize>
pub const fn available(self) -> Option<usize>
Returns the number of currently available input units for this kind, if available.
Returns
Some(available)forSelf::IncompleteSequence;Nonefor all other variants.
Sourcepub const fn value(self) -> Option<u32>
pub const fn value(self) -> Option<u32>
Returns the raw malformed value associated with this decoding error, if any.
Returns
Some(value)forSelf::MalformedSequencewhen a specific malformed unit value is available.Some(value)forSelf::InvalidCodePoint.Nonefor other variants.