pub struct CharsetDecodeError { /* private fields */ }Expand description
Error reported by a charset decoder.
The error always carries the charset, error kind, and input unit index at
which the failure was detected. Errors that decode a raw numeric value, such
as invalid UTF-32 units, carry that value through Self::kind and
Self::value.
Implementations
Sourceimpl CharsetDecodeError
impl CharsetDecodeError
Sourcepub const fn new(
charset: Charset,
kind: CharsetDecodeErrorKind,
index: usize,
) -> Self
pub const fn new( charset: Charset, kind: CharsetDecodeErrorKind, index: usize, ) -> Self
Sourcepub const fn kind(self) -> CharsetDecodeErrorKind
pub const fn kind(self) -> CharsetDecodeErrorKind
Sourcepub const fn index(self) -> usize
pub const fn index(self) -> usize
Returns the input unit index associated with this error.
Returns
Returns the index at which the error was detected.
Sourcepub const fn required(self) -> Option<usize>
pub const fn required(self) -> Option<usize>
Returns required input units for this decoding error, if reported.
Returns
Returns Some(required) for CharsetDecodeErrorKind::IncompleteSequence,
otherwise None.
Sourcepub const fn available(self) -> Option<usize>
pub const fn available(self) -> Option<usize>
Returns available input units for this decoding error, if reported.
Returns
Returns Some(available) for CharsetDecodeErrorKind::IncompleteSequence,
otherwise None.