pub struct CoderProgress { /* private fields */ }Expand description
Counts how much work a crate::Coder completed before returning.
Implementations
Sourceimpl CoderProgress
impl CoderProgress
Sourcepub const fn new(
status: CoderStatus,
read: usize,
written: usize,
) -> CoderProgress
pub const fn new( status: CoderStatus, read: usize, written: usize, ) -> CoderProgress
Sourcepub const fn complete(read: usize, written: usize) -> CoderProgress
pub const fn complete(read: usize, written: usize) -> CoderProgress
Creates a completed progress value.
Parameters
read: Number of consumed input units.written: Number of produced output units.
Returns
Returns a progress value whose status is CoderStatus::Complete.
Sourcepub const fn status(self) -> CoderStatus
pub const fn status(self) -> CoderStatus
Sourcepub const fn read(self) -> usize
pub const fn read(self) -> usize
Returns the number of input units consumed by the call.
Returns
Returns a count relative to the input index passed to the conversion call.
Sourcepub const fn written(self) -> usize
pub const fn written(self) -> usize
Returns the number of output units written by the call.
Returns
Returns a count relative to the output index passed to the conversion call.
Sourcepub const fn required(self) -> usize
pub const fn required(self) -> usize
Returns the additional unit count required by the reported status.
Returns
Returns 0 when conversion completed.
Sourcepub const fn index(self) -> Option<usize>
pub const fn index(self) -> Option<usize>
Returns the absolute boundary index associated with this status, if any.
- For
CoderStatus::NeedInput, returnsinput_index. - For
CoderStatus::NeedOutput, returnsoutput_index. - For
CoderStatus::Complete, returnsNone.