pub struct Utf16ByteCodec { /* private fields */ }Expand description
Combined byte-serialized UTF-16 codec.
The codec uses one configured byte order for both decoding and encoding. It
does not detect, consume, or emit a BOM automatically; callers should use
crate::UnicodeBom when a byte stream may carry an explicit BOM.
Examples
use qubit_text_codec::{
ByteOrder,
CharsetCodec,
DecodeStatus,
Charset,
Utf16,
Utf16ByteCodec,
};
let codec = Utf16ByteCodec::new(ByteOrder::LittleEndian);
assert_eq!(Charset::UTF_16LE, codec.charset());
assert_eq!(Utf16::MAX_BYTES_PER_CHAR, codec.max_units_per_char());
let mut output = [0_u8; Utf16::MAX_BYTES_PER_CHAR];
let written = codec.encode_one('😀', &mut output, 0).expect("buffer fits");
assert_eq!(
DecodeStatus::Complete {
value: '😀',
consumed: written,
},
codec.decode_one(&output[..written], 0).expect("valid UTF-16LE"),
);Implementations
Sourceimpl Utf16ByteCodec
impl Utf16ByteCodec
Sourcepub const fn byte_order(self) -> ByteOrder
pub const fn byte_order(self) -> ByteOrder
Sourcepub const fn charset(self) -> Charset
pub const fn charset(self) -> Charset
Returns the fixed-endian UTF-16 charset descriptor.
Returns
Returns Charset::UTF_16LE or Charset::UTF_16BE according to this
codec’s configured byte order.
Sourcepub const fn max_units_per_char(self) -> usize
pub const fn max_units_per_char(self) -> usize
Returns the maximum number of serialized UTF-16 bytes for one character.
Returns
Returns Utf16::MAX_BYTES_PER_CHAR.